﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using System.Linq;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Problems.DataAnalysis {
  /// <summary>
  /// Represents a weight calculator that gives every classification solution a weight based on the accuracy.
  /// </summary>
  [StorableClass]
  [Item("AccuracyWeightCalculator", "Represents a weight calculator that gives every classification solution a weight based on the accuracy.")]
  public class AccuracyWeightCalculator : WeightCalculator {

    public AccuracyWeightCalculator()
      : base() {
    }

    [StorableConstructor]
    protected AccuracyWeightCalculator(bool deserializing) : base(deserializing) { }
    protected AccuracyWeightCalculator(AccuracyWeightCalculator original, Cloner cloner)
      : base(original, cloner) {
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new AccuracyWeightCalculator(this, cloner);
    }

    public override IEnumerable<double> CalculateWeights(ItemCollection<IClassificationSolution> classificationSolutions) {
      double sum = classificationSolutions.Select(s => s.TestAccuracy).Sum();
      List<double> weights = new List<double>();
      foreach (var item in classificationSolutions) {
        weights.Add(item.TestAccuracy / sum);
      }
      return weights;
    }
  }
}
